xquery version "3.1";

module namespace website="http://ahikar.sub.uni-goettingen.de/ns/website";

import module namespace commons="http://ahikar.sub.uni-goettingen.de/ns/commons" at "commons.xqm";
import module namespace rest="http://exquery.org/ns/restxq";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace tgmd="http://textgrid.info/namespaces/metadata/core/2010";
declare namespace xhtml="http://www.w3.org/1999/xhtml";
declare namespace output="http://www.w3.org/2010/xslt-xquery-serialization";

declare
    %rest:GET
    %rest:HEAD
    %rest:path("/website/manuscripts/{$lang}")
    %output:method("xml")
function website:manuscripts($lang) {
    let $teiHeaders := (collection($commons:data)//tei:TEI[tei:teiHeader//tei:language/@ident eq "syc"]//tei:teiHeader)
    return
    element xhtml:div {
        attribute class { "manuscripts" },
        for $teiHeader at $pos in $teiHeaders
        where $pos
        let $syriac := true()
        let $lang := if($syriac) then "syriac" else "arabic-karshuni"
        let $meta := doc( $commons:meta || ($teiHeader/base-uri() => tokenize("/"))[last()])
        let $tgUri := ($teiHeader/base-uri() => tokenize("/"))[last()] => substring-before(".xml")
        let $msUri := $tgUri => commons:get-parent-uri()
        let $firstpage := string(($teiHeader/root()//tei:pb[@facs][@n])[1]/@n)
        let $url := "https://ahikar.sub.uni-goettingen.de/" || $lang || "/#/?source=external&amp;redirectUrl=https%3A%2F%2Fahikar.sub.uni-goettingen.de%2Fwebsite%2F&amp;itemurl=https%3A%2F%2Fahikar.sub.uni-goettingen.de%2Fapi%2Ftextapi%2Fahikar%2F" || $lang || "%2F" || $msUri || "-" || $firstpage || "%2Flatest%2Fitem.json"
    
        let $title := $meta//tgmd:title/text()
        let $xhtmlTitle :=
            element xhtml:h2 {
                codepoints-to-string(64 + $pos) || ".",
                string($title),
                element xhtml:a {
                    attribute href { $url },
                    "🔗"
                }
            }
    
        let $msIdentifier := $teiHeader//tei:msIdentifier
        let $xhtmlMsIdentifier :=
            element xhtml:div {
                attribute class { "msIdentifier" },
                element xhtml:h3 { "Manuscript Identifier" },
                element xhtml:div {
                ($msIdentifier/tei:institution/string(),
                $msIdentifier/tei:idno/string(),
                $msIdentifier/tei:settlement/string() => normalize-space()
            ) => string-join("; ")},
                $msIdentifier//tei:idno[starts-with(., "http")] ! element xhtml:a {
                    attribute class { "link-to-source" },
                    attribute href {string(.)},
                    "Digital Source"
                }
            }
        let $xhtmlMsItem :=
            element xhtml:div {
                attribute class { "msItem" },
                $teiHeader//tei:msItem//text()[normalize-space(.) ne ""]
            => string-join("; ")
            }
    
        let $history := $teiHeader//tei:history
        let $xhtmlHistory :=
            element xhtml:div {
                element xhtml:h3 { "History" },
                element xhtml:ul {
                    attribute class {"history"},
                    element xhtml:li {"type: " || $history//tei:objectType},
                    element xhtml:li {"origin: " || $history//tei:country || ", " || $history//tei:placeName},
                    element xhtml:li {"date: " || $history//tei:date}
                }
            }

        let $listBibl := $teiHeader//tei:listBibl/tei:bibl
        let $xhtmlListBibl :=
            element xhtml:div {
                element xhtml:h3 { "Bibliography" },
                element xhtml:ul {
                    attribute class {"listBibl"},
                    for $bibl in $listBibl
                    return
                        element xhtml:li { normalize-space($bibl) }
                }
            }
    
        let $abstract := $teiHeader//tei:abstract
        let $xhtmlAbstract :=
            element xhtml:div {
                attribute class {"abstract"},
                element xhtml:h3 { "Editor`s statements" },
                for $p in $abstract//tei:p
                return
                    element xhtml:p { normalize-space($p) }
            }
    
        return
            element xhtml:div {
                attribute class { "manuscript" },
                $xhtmlTitle,
                $xhtmlMsIdentifier,
                $xhtmlMsItem,
                $xhtmlHistory,
                $xhtmlListBibl,
                $xhtmlAbstract
            }
    }
};
